@@ -25,8 +25,6 @@ import (
 	"sort"
 	"strconv"
 	"strings"
-	"sync"
-	"time"
 
 	"go.uber.org/zap"
 
@@ -46,58 +44,6 @@ func (q Quantity) string() string {
 	return strconv.FormatInt(int64(q), 10)
 }
 
-// Util struct to keep track of application resource usage
-type TrackedResource struct {
-	// Two level map for aggregated resource usage
-	// With instance type being the top level key, the mapped value is a map:
-	//   resource type (CPU, memory etc) -> the aggregated used time (in seconds) of the resource type
-	//
-	TrackedResourceMap map[string]map[string]int64
-
-	sync.RWMutex
-}
-
-func (ur *TrackedResource) Clone() *TrackedResource {
-	if ur == nil {
-		return nil
-	}
-	ret := NewTrackedResource()
-	ur.RLock()
-	defer ur.RUnlock()
-	for k, v := range ur.TrackedResourceMap {
-		dest := make(map[string]int64)
-		for key, element := range v {
-			dest[key] = element
-		}
-		ret.TrackedResourceMap[k] = dest
-	}
-	return ret
-}
-
-// Aggregate the resource usage to UsedResourceMap[instType]
-// The time the given resource used is the delta between the resource createTime and currentTime
-func (ur *TrackedResource) AggregateTrackedResource(instType string,
-	resource *Resource, bindTime time.Time) {
-	ur.Lock()
-	defer ur.Unlock()
-
-	releaseTime := time.Now()
-	timeDiff := int64(releaseTime.Sub(bindTime).Seconds())
-	aggregatedResourceTime, ok := ur.TrackedResourceMap[instType]
-	if !ok {
-		aggregatedResourceTime = map[string]int64{}
-	}
-	for key, element := range resource.Resources {
-		curUsage, ok := aggregatedResourceTime[key]
-		if !ok {
-			curUsage = 0
-		}
-		curUsage += int64(element) * timeDiff // resource size times timeDiff
-		aggregatedResourceTime[key] = curUsage
-	}
-	ur.TrackedResourceMap[instType] = aggregatedResourceTime
-}
-
 // Never update value of Zero
 var Zero = NewResource()
 
@@ -157,10 +103,6 @@ func NewResourceFromConf(configMap map[string]string) (*Resource, error) {
 	return res, nil
 }
 
-func NewTrackedResource() *TrackedResource {
-	return &TrackedResource{TrackedResourceMap: make(map[string]map[string]int64)}
-}
-
 func (r *Resource) String() string {
 	if r == nil {
 		return "nil resource"
@@ -475,14 +417,14 @@ func subNonNegative(left, right *Resource) (*Resource, string) {
 	return out, message
 }
 
-// Check if smaller fits in larger
-// Types not defined in the larger resource are considered 0 values for Quantity
-// A nil resource is treated as an empty resource (all types are 0)
-func FitIn(larger, smaller *Resource) bool {
-	return larger.fitIn(smaller, false)
+// FitIn checks if smaller fits in the defined resource
+// Types not defined in resource this is called against are considered 0 for Quantity
+// A nil resource is treated as an empty resource (no types defined)
+func (r *Resource) FitIn(smaller *Resource) bool {
+	return r.fitIn(smaller, false)
 }
 
-// Check if smaller fits in the defined resource
+// FitInMaxUndef checks if smaller fits in the defined resource
 // Types not defined in resource this is called against are considered the maximum value for Quantity
 // A nil resource is treated as an empty resource (no types defined)
 func (r *Resource) FitInMaxUndef(smaller *Resource) bool {
@@ -508,9 +450,7 @@ func (r *Resource) fitIn(smaller *Resource, skipUndef bool) bool {
 		if skipUndef && !ok {
 			continue
 		}
-		if largerValue < 0 {
-			largerValue = 0
-		}
+		largerValue = max(0, largerValue)
 		if v > largerValue {
 			return false
 		}
@@ -832,22 +772,6 @@ func StrictlyGreaterThanZero(larger *Resource) bool {
 	return greater
 }
 
-// Return the smallest quantity
-func MinQuantity(x, y Quantity) Quantity {
-	if x < y {
-		return x
-	}
-	return y
-}
-
-// Return the largest quantity
-func MaxQuantity(x, y Quantity) Quantity {
-	if x > y {
-		return x
-	}
-	return y
-}
-
 // Returns a new resource with the smallest value for each quantity in the resources
 // If either resource passed in is nil a zero resource is returned
 // If a resource type is missing from one of the Resource, it is considered 0
@@ -855,10 +779,10 @@ func ComponentWiseMin(left, right *Resource) *Resource {
 	out := NewResource()
 	if left != nil && right != nil {
 		for k, v := range left.Resources {
-			out.Resources[k] = MinQuantity(v, right.Resources[k])
+			out.Resources[k] = min(v, right.Resources[k])
 		}
 		for k, v := range right.Resources {
-			out.Resources[k] = MinQuantity(v, left.Resources[k])
+			out.Resources[k] = min(v, left.Resources[k])
 		}
 	}
 	return out
@@ -880,14 +804,14 @@ func ComponentWiseMinPermissive(left, right *Resource) *Resource {
 	}
 	for k, v := range left.Resources {
 		if val, ok := right.Resources[k]; ok {
-			out.Resources[k] = MinQuantity(v, val)
+			out.Resources[k] = min(v, val)
 		} else {
 			out.Resources[k] = v
 		}
 	}
 	for k, v := range right.Resources {
 		if val, ok := left.Resources[k]; ok {
-			out.Resources[k] = MinQuantity(v, val)
+			out.Resources[k] = min(v, val)
 		} else {
 			out.Resources[k] = v
 		}
@@ -918,10 +842,10 @@ func ComponentWiseMax(left, right *Resource) *Resource {
 	out := NewResource()
 	if left != nil && right != nil {
 		for k, v := range left.Resources {
-			out.Resources[k] = MaxQuantity(v, right.Resources[k])
+			out.Resources[k] = max(v, right.Resources[k])
 		}
 		for k, v := range right.Resources {
-			out.Resources[k] = MaxQuantity(v, left.Resources[k])
+			out.Resources[k] = max(v, left.Resources[k])
 		}
 	}
 	return out
