@@ -24,7 +24,6 @@ import (
 	"fmt"
 	"strconv"
 	"strings"
-	"sync"
 	"time"
 
 	"github.com/looplab/fsm"
@@ -35,6 +34,7 @@ import (
 	"github.com/apache/yunikorn-core/pkg/common/resources"
 	"github.com/apache/yunikorn-core/pkg/common/security"
 	"github.com/apache/yunikorn-core/pkg/events"
+	"github.com/apache/yunikorn-core/pkg/locking"
 	"github.com/apache/yunikorn-core/pkg/log"
 	"github.com/apache/yunikorn-core/pkg/metrics"
 	"github.com/apache/yunikorn-core/pkg/scheduler/objects/template"
@@ -89,7 +89,7 @@ type Queue struct {
 	template               *template.Template
 	queueEvents            *queueEvents
 
-	sync.RWMutex
+	locking.RWMutex
 }
 
 // newBlankQueue creates a new empty queue objects with all values initialised.
@@ -131,19 +131,21 @@ func NewConfiguredQueue(conf configs.QueueConfig, parent *Queue) (*Queue, error)
 	// add to the parent, we might have an overall lock already
 	// still need to make sure we lock the parent so we do not interfere with scheduling
 	if parent != nil {
+		// pull the properties from the parent that should be set on the child
+		sq.mergeProperties(parent.getProperties(), conf.Properties)
+		sq.UpdateQueueProperties()
 		sq.QueuePath = parent.QueuePath + configs.DOT + sq.Name
 		err := parent.addChildQueue(sq)
 		if err != nil {
 			return nil, fmt.Errorf("configured queue creation failed: %w", err)
 		}
-		// pull the properties from the parent that should be set on the child
-		sq.mergeProperties(parent.getProperties(), conf.Properties)
+	} else {
+		sq.UpdateQueueProperties()
 	}
-	sq.UpdateQueueProperties()
-	sq.queueEvents = newQueueEvents(sq, events.GetEventSystem())
+	sq.queueEvents = newQueueEvents(events.GetEventSystem())
 	log.Log(log.SchedQueue).Info("configured queue added to scheduler",
 		zap.String("queueName", sq.QueuePath))
-	sq.queueEvents.sendNewQueueEvent()
+	sq.queueEvents.sendNewQueueEvent(sq.QueuePath, sq.isManaged)
 
 	return sq, nil
 }
@@ -198,10 +200,10 @@ func newDynamicQueueInternal(name string, leaf bool, parent *Queue) (*Queue, err
 	}
 
 	sq.UpdateQueueProperties()
-	sq.queueEvents = newQueueEvents(sq, events.GetEventSystem())
+	sq.queueEvents = newQueueEvents(events.GetEventSystem())
 	log.Log(log.SchedQueue).Info("dynamic queue added to scheduler",
 		zap.String("queueName", sq.QueuePath))
-	sq.queueEvents.sendNewQueueEvent()
+	sq.queueEvents.sendNewQueueEvent(sq.QueuePath, sq.isManaged)
 
 	return sq, nil
 }
@@ -336,7 +338,7 @@ func (sq *Queue) applyConf(conf configs.QueueConfig) error {
 	}
 
 	if prevLeaf != sq.isLeaf && sq.queueEvents != nil {
-		sq.queueEvents.sendTypeChangedEvent()
+		sq.queueEvents.sendTypeChangedEvent(sq.QueuePath, sq.isLeaf)
 	}
 
 	if !sq.isLeaf {
@@ -382,7 +384,7 @@ func (sq *Queue) setResources(resource configs.Resources) error {
 			zap.Stringer("current", sq.maxResource),
 			zap.Stringer("new", maxResource))
 		if !resources.Equals(sq.maxResource, maxResource) && sq.queueEvents != nil {
-			sq.queueEvents.sendMaxResourceChangedEvent()
+			sq.queueEvents.sendMaxResourceChangedEvent(sq.QueuePath, maxResource)
 		}
 		sq.maxResource = maxResource
 		sq.updateMaxResourceMetrics()
@@ -392,7 +394,7 @@ func (sq *Queue) setResources(resource configs.Resources) error {
 			zap.Stringer("current", sq.maxResource),
 			zap.Stringer("new", maxResource))
 		if sq.queueEvents != nil {
-			sq.queueEvents.sendMaxResourceChangedEvent()
+			sq.queueEvents.sendMaxResourceChangedEvent(sq.QueuePath, maxResource)
 		}
 		sq.maxResource = nil
 		sq.updateMaxResourceMetrics()
@@ -408,7 +410,7 @@ func (sq *Queue) setResources(resource configs.Resources) error {
 			zap.Stringer("current", sq.guaranteedResource),
 			zap.Stringer("new", guaranteedResource))
 		if !resources.Equals(sq.guaranteedResource, guaranteedResource) && sq.queueEvents != nil {
-			sq.queueEvents.sendGuaranteedResourceChangedEvent()
+			sq.queueEvents.sendGuaranteedResourceChangedEvent(sq.QueuePath, guaranteedResource)
 		}
 		sq.guaranteedResource = guaranteedResource
 		sq.updateGuaranteedResourceMetrics()
@@ -418,7 +420,7 @@ func (sq *Queue) setResources(resource configs.Resources) error {
 			zap.Stringer("current", sq.guaranteedResource),
 			zap.Stringer("new", guaranteedResource))
 		if sq.queueEvents != nil {
-			sq.queueEvents.sendGuaranteedResourceChangedEvent()
+			sq.queueEvents.sendGuaranteedResourceChangedEvent(sq.QueuePath, guaranteedResource)
 		}
 		sq.guaranteedResource = nil
 		sq.updateGuaranteedResourceMetrics()
@@ -635,6 +637,7 @@ func (sq *Queue) GetPartitionQueueDAOInfo(exclude bool) dao.PartitionQueueDAOInf
 		}
 	}
 	// we have held the read lock so following method should not take lock again.
+	queueInfo.HeadRoom = sq.getHeadRoom().DAOMap()
 	sq.RLock()
 	defer sq.RUnlock()
 
@@ -648,7 +651,6 @@ func (sq *Queue) GetPartitionQueueDAOInfo(exclude bool) dao.PartitionQueueDAOInf
 	queueInfo.GuaranteedResource = sq.guaranteedResource.DAOMap()
 	queueInfo.AllocatedResource = sq.allocatedResource.DAOMap()
 	queueInfo.PreemptingResource = sq.preemptingResource.DAOMap()
-	queueInfo.HeadRoom = sq.getHeadRoom().DAOMap()
 	queueInfo.IsLeaf = sq.isLeaf
 	queueInfo.IsManaged = sq.isManaged
 	queueInfo.CurrentPriority = sq.getCurrentPriority()
@@ -726,8 +728,7 @@ func (sq *Queue) AddApplication(app *Application) {
 	defer sq.Unlock()
 	appID := app.ApplicationID
 	sq.applications[appID] = app
-	sq.appPriorities[appID] = app.GetAskMaxPriority()
-	sq.queueEvents.sendNewApplicationEvent(appID)
+	sq.queueEvents.sendNewApplicationEvent(sq.QueuePath, appID)
 	// YUNIKORN-199: update the quota from the namespace
 	// get the tag with the quota
 	quota := app.GetTag(siCommon.AppTagNamespaceResourceQuota)
@@ -799,7 +800,7 @@ func (sq *Queue) RemoveApplication(app *Application) {
 			zap.String("applicationID", appID))
 		return
 	}
-	sq.queueEvents.sendRemoveApplicationEvent(appID)
+	sq.queueEvents.sendRemoveApplicationEvent(sq.QueuePath, appID)
 	if appPending := app.GetPendingResource(); !resources.IsZero(appPending) {
 		sq.decPendingResource(appPending)
 	}
@@ -918,7 +919,7 @@ func (sq *Queue) addChildQueue(child *Queue) error {
 
 	// no need to lock child as it is a new queue which cannot be accessed yet
 	sq.children[child.Name] = child
-	sq.childPriorities[child.Name] = child.GetCurrentPriority()
+	sq.childPriorities[child.Name] = child.getCurrentPriority()
 
 	if child.isLeaf {
 		// managed (configured) leaf queue can't use template
@@ -949,27 +950,32 @@ func (sq *Queue) addChildQueue(child *Queue) error {
 // This can be executed multiple times and is only effective the first time.
 // This is a noop on an unmanaged queue.
 func (sq *Queue) MarkQueueForRemoval() {
-	// need to lock for write as we don't want to add a queue while marking for removal
-	sq.Lock()
-	defer sq.Unlock()
+	if !sq.IsManaged() {
+		return
+	}
+	children := sq.GetCopyOfChildren()
 	// Mark the managed queue for deletion: it is removed from the config let it drain.
 	// Also mark all the managed children for deletion.
-	if sq.isManaged {
-		log.Log(log.SchedQueue).Info("marking managed queue for deletion",
-			zap.String("queue", sq.QueuePath))
-		if err := sq.handleQueueEvent(Remove); err != nil {
-			log.Log(log.SchedQueue).Warn("failed to mark managed queue for deletion",
-				zap.String("queue", sq.QueuePath),
-				zap.Error(err))
-		}
-		if len(sq.children) > 0 {
-			for _, child := range sq.children {
-				child.MarkQueueForRemoval()
-			}
+	log.Log(log.SchedQueue).Info("marking managed queue for deletion",
+		zap.String("queue", sq.QueuePath))
+	sq.doRemoveQueue()
+	if len(sq.children) > 0 {
+		for _, child := range children {
+			child.MarkQueueForRemoval()
 		}
 	}
 }
 
+func (sq *Queue) doRemoveQueue() {
+	sq.Lock()
+	defer sq.Unlock()
+	if err := sq.handleQueueEvent(Remove); err != nil {
+		log.Log(log.SchedQueue).Warn("failed to mark managed queue for deletion",
+			zap.String("queue", sq.QueuePath),
+			zap.Error(err))
+	}
+}
+
 // GetChildQueue returns a queue if the name exists in the child map as a key.
 func (sq *Queue) GetChildQueue(name string) *Queue {
 	sq.RLock()
@@ -996,7 +1002,7 @@ func (sq *Queue) RemoveQueue() bool {
 	log.Log(log.SchedQueue).Info("removing queue", zap.String("queue", sq.QueuePath))
 	// root is always managed and is the only queue with a nil parent: no need to guard
 	sq.parent.removeChildQueue(sq.Name)
-	sq.queueEvents.sendRemoveQueueEvent()
+	sq.queueEvents.sendRemoveQueueEvent(sq.QueuePath, sq.isManaged)
 	return true
 }
 
@@ -1022,13 +1028,10 @@ func (sq *Queue) isRoot() bool {
 // IncAllocatedResource increments the allocated resources for this queue (recursively).
 // Guard against going over max resources if set
 func (sq *Queue) IncAllocatedResource(alloc *resources.Resource, nodeReported bool) error {
-	sq.Lock()
-	defer sq.Unlock()
-
 	// check this queue: failure stops checks if the allocation is not part of a node addition
 	newAllocated := resources.Add(sq.allocatedResource, alloc)
 	if !nodeReported {
-		if !sq.maxResource.FitInMaxUndef(newAllocated) {
+		if !sq.resourceFitsMaxRes(newAllocated) {
 			return fmt.Errorf("allocation (%v) puts queue '%s' over maximum allocation (%v), current usage (%v)",
 				alloc, sq.QueuePath, sq.maxResource, sq.allocatedResource)
 		}
@@ -1049,23 +1052,30 @@ func (sq *Queue) IncAllocatedResource(alloc *resources.Resource, nodeReported bo
 			return err
 		}
 	}
+	sq.Lock()
+	defer sq.Unlock()
 	// all OK update this queue
 	sq.allocatedResource = newAllocated
 	sq.updateAllocatedResourceMetrics()
 	return nil
 }
 
+// small helper method to access sq.maxResource and avoid Clone() call
+func (sq *Queue) resourceFitsMaxRes(res *resources.Resource) bool {
+	sq.RLock()
+	defer sq.RUnlock()
+	return sq.maxResource.FitInMaxUndef(res)
+}
+
 // DecAllocatedResource decrement the allocated resources for this queue (recursively)
 // Guard against going below zero resources.
 func (sq *Queue) DecAllocatedResource(alloc *resources.Resource) error {
 	if sq == nil {
 		return fmt.Errorf("queue is nil")
 	}
-	sq.Lock()
-	defer sq.Unlock()
 
 	// check this queue: failure stops checks
-	if alloc != nil && !sq.allocatedResource.FitIn(alloc) {
+	if alloc != nil && !sq.resourceFitsAllocated(alloc) {
 		return fmt.Errorf("released allocation (%v) is larger than '%s' queue allocation (%v)",
 			alloc, sq.QueuePath, sq.allocatedResource)
 	}
@@ -1085,12 +1095,21 @@ func (sq *Queue) DecAllocatedResource(alloc *resources.Resource) error {
 			return err
 		}
 	}
+	sq.Lock()
+	defer sq.Unlock()
 	// all OK update the queue
 	sq.allocatedResource = resources.Sub(sq.allocatedResource, alloc)
 	sq.updateAllocatedResourceMetrics()
 	return nil
 }
 
+// small helper method to access sq.allocatedResource and avoid Clone() call
+func (sq *Queue) resourceFitsAllocated(res *resources.Resource) bool {
+	sq.RLock()
+	defer sq.RUnlock()
+	return sq.allocatedResource.FitIn(res)
+}
+
 // IncPreemptingResource increments the preempting resources for this queue (recursively).
 func (sq *Queue) IncPreemptingResource(alloc *resources.Resource) {
 	if sq == nil {
@@ -1304,7 +1323,7 @@ func (sq *Queue) SetMaxResource(max *resources.Resource) {
 			zap.Stringer("current", sq.maxResource),
 			zap.Stringer("new", max))
 		if !resources.Equals(sq.maxResource, max) && sq.queueEvents != nil {
-			sq.queueEvents.sendMaxResourceChangedEvent()
+			sq.queueEvents.sendMaxResourceChangedEvent(sq.QueuePath, sq.maxResource)
 		}
 		sq.maxResource = max.Clone()
 		sq.updateMaxResourceMetrics()
@@ -1314,7 +1333,7 @@ func (sq *Queue) SetMaxResource(max *resources.Resource) {
 			zap.Stringer("current", sq.maxResource),
 			zap.Stringer("new", max))
 		if sq.queueEvents != nil {
-			sq.queueEvents.sendMaxResourceChangedEvent()
+			sq.queueEvents.sendMaxResourceChangedEvent(sq.QueuePath, sq.maxResource)
 		}
 		sq.maxResource = nil
 		sq.updateMaxResourceMetrics()
@@ -1970,7 +1989,3 @@ func (sq *Queue) recalculatePriority() int32 {
 	sq.currentPriority = curr
 	return priorityValueByPolicy(sq.priorityPolicy, sq.priorityOffset, curr)
 }
-
-func (sq *Queue) SendRemoveQueueEvent() {
-	sq.queueEvents.sendRemoveQueueEvent()
-}
