@@ -23,6 +23,7 @@ import (
 	"testing"
 	"time"
 
+	"github.com/google/btree"
 	"gotest.tools/v3/assert"
 
 	"github.com/apache/yunikorn-core/pkg/common/configs"
@@ -35,13 +36,14 @@ import (
 )
 
 const (
-	appID0    = "app-0"
-	appID1    = "app-1"
-	appID2    = "app-2"
-	aKey      = "alloc-1"
-	aUUID     = "alloc-uuid-1"
-	nodeID1   = "node-1"
-	instType1 = "itype-1"
+	appID0        = "app-0"
+	appID1        = "app-1"
+	appID2        = "app-2"
+	aKey          = "alloc-1"
+	aAllocationID = "alloc-allocationid-1"
+	nodeID1       = "node-1"
+	nodeID2       = "node-2"
+	instType1     = "itype-1"
 )
 
 // Create the root queue, base for all testing
@@ -208,18 +210,18 @@ func newProto(nodeID string, totalResource, occupiedResource *resources.Resource
 }
 
 // Create a new Allocation with a random ask key
-func newAllocation(appID, uuid, nodeID string, res *resources.Resource) *Allocation {
+func newAllocation(appID, nodeID string, res *resources.Resource) *Allocation {
 	askKey := strconv.FormatInt((time.Now()).UnixNano(), 10)
 	ask := newAllocationAsk(askKey, appID, res)
-	return NewAllocation(uuid, nodeID, ask)
+	return NewAllocation(nodeID, ask)
 }
 
 // Create a new Allocation with a random ask key
-func newPlaceholderAlloc(appID, uuid, nodeID string, res *resources.Resource) *Allocation {
+func newPlaceholderAlloc(appID, nodeID string, res *resources.Resource) *Allocation {
 	askKey := strconv.FormatInt((time.Now()).UnixNano(), 10)
 	ask := newAllocationAsk(askKey, appID, res)
 	ask.placeholder = true
-	return NewAllocation(uuid, nodeID, ask)
+	return NewAllocation(nodeID, ask)
 }
 
 func newAllocationAsk(allocKey, appID string, res *resources.Resource) *AllocationAsk {
@@ -275,3 +277,18 @@ func assertUserResourcesAndGroupResources(t *testing.T, userGroup security.UserG
 	assert.Equal(t, resources.Equals(userResource, expectedUserResources), true)
 	assert.Equal(t, resources.Equals(groupResource, expectedGroupResources), true)
 }
+
+func getNodeIteratorFn(nodes ...*Node) func() NodeIterator {
+	tree := btree.New(7)
+	for _, node := range nodes {
+		tree.ReplaceOrInsert(nodeRef{
+			node, 1,
+		})
+	}
+
+	return func() NodeIterator {
+		return NewTreeIterator(acceptAll, func() *btree.BTree {
+			return tree
+		})
+	}
+}
