@@ -24,7 +24,6 @@ import (
 	"math"
 	"strconv"
 	"strings"
-	"sync"
 	"time"
 
 	"github.com/looplab/fsm"
@@ -34,6 +33,7 @@ import (
 	"github.com/apache/yunikorn-core/pkg/common/configs"
 	"github.com/apache/yunikorn-core/pkg/common/resources"
 	"github.com/apache/yunikorn-core/pkg/common/security"
+	"github.com/apache/yunikorn-core/pkg/locking"
 	"github.com/apache/yunikorn-core/pkg/log"
 	"github.com/apache/yunikorn-core/pkg/metrics"
 	"github.com/apache/yunikorn-core/pkg/scheduler/objects"
@@ -58,7 +58,6 @@ type PartitionContext struct {
 	partitionManager       *partitionManager               // manager for this partition
 	stateMachine           *fsm.FSM                        // the state of the partition for scheduling
 	stateTime              time.Time                       // last time the state was updated (needed for cleanup)
-	rules                  *[]configs.PlacementRule        // placement rules to be loaded by the scheduler
 	userGroupCache         *security.UserGroupCache        // user cache per partition
 	totalPartitionResource *resources.Resource             // Total node resources
 	allocations            int                             // Number of allocations on the partition
@@ -75,7 +74,7 @@ type PartitionContext struct {
 	// while manipulating the application.
 	// Similarly adding, updating or removing a node or a queue should only hold the partition write lock
 	// while manipulating the partition information not while manipulating the underlying objects.
-	sync.RWMutex
+	locking.RWMutex
 }
 
 func newPartitionContext(conf configs.PartitionConfig, rmID string, cc *ClusterContext) (*PartitionContext, error) {
@@ -124,10 +123,9 @@ func (pc *PartitionContext) initialPartitionFromConfig(conf configs.PartitionCon
 		zap.String("partitionName", pc.Name),
 		zap.String("rmID", pc.RmID))
 
-	pc.rules = &conf.PlacementRules
 	// We need to pass in the locked version of the GetQueue function.
 	// Placing an application will not have a lock on the partition context.
-	pc.placementManager = placement.NewPlacementManager(*pc.rules, pc.GetQueue)
+	pc.placementManager = placement.NewPlacementManager(conf.PlacementRules, pc.GetQueue)
 	// get the user group cache for the partition
 	// TODO get the resolver from the config
 	pc.userGroupCache = security.GetUserGroupCache("")
@@ -159,19 +157,21 @@ func (pc *PartitionContext) updatePreemption(conf configs.PartitionConfig) {
 }
 
 func (pc *PartitionContext) updatePartitionDetails(conf configs.PartitionConfig) error {
-	pc.Lock()
-	defer pc.Unlock()
+	// the following piece of code (before pc.Lock()) must be performed without locking
+	// to avoid lock order differences between PartitionContext and AppPlacementManager
 	if len(conf.Queues) == 0 || conf.Queues[0].Name != configs.RootQueue {
 		return fmt.Errorf("partition cannot be created without root queue")
 	}
 	log.Log(log.SchedPartition).Info("Updating placement manager rules on config reload")
-	err := pc.placementManager.UpdateRules(conf.PlacementRules)
+	err := pc.getPlacementManager().UpdateRules(conf.PlacementRules)
 	if err != nil {
 		log.Log(log.SchedPartition).Info("New placement rules not activated, config reload failed", zap.Error(err))
 		return err
 	}
-	pc.rules = &conf.PlacementRules
 	pc.updateNodeSortingPolicy(conf)
+
+	pc.Lock()
+	defer pc.Unlock()
 	pc.updatePreemption(conf)
 	// start at the root: there is only one queue
 	queueConf := conf.Queues[0]
@@ -531,9 +531,6 @@ func (pc *PartitionContext) createQueue(name string, user security.UserGroup) (*
 
 // Get a node from the partition by nodeID.
 func (pc *PartitionContext) GetNode(nodeID string) *objects.Node {
-	pc.RLock()
-	defer pc.RUnlock()
-
 	return pc.nodes.GetNode(nodeID)
 }
 
@@ -589,18 +586,24 @@ func (pc *PartitionContext) updatePartitionResource(delta *resources.Resource) {
 	}
 }
 
-// Update the partition details when removing a node.
-// This locks the partition. The partition may not be locked when we process the allocation
-// additions to the node as that takes further app, queue or node locks
+// Update the partition details when adding a node.
 func (pc *PartitionContext) addNodeToList(node *objects.Node) error {
-	pc.Lock()
-	defer pc.Unlock()
-	// Node can be added to the system to allow processing of the allocations
+	// we don't grab a lock here because we only update pc.nodes which is internally protected
 	if err := pc.nodes.AddNode(node); err != nil {
 		return fmt.Errorf("failed to add node %s to partition %s, error: %v", node.NodeID, pc.Name, err)
 	}
-	metrics.GetSchedulerMetrics().IncActiveNodes()
 
+	pc.addNodeResources(node)
+	return nil
+}
+
+// Update metrics & resource tracking information.
+// This locks the partition. The partition may not be locked when we process the allocation
+// additions to the node as that takes further app, queue or node locks.
+func (pc *PartitionContext) addNodeResources(node *objects.Node) {
+	pc.Lock()
+	defer pc.Unlock()
+	metrics.GetSchedulerMetrics().IncActiveNodes()
 	// update/set the resources available in the cluster
 	if pc.totalPartitionResource == nil {
 		pc.totalPartitionResource = node.GetCapacity().Clone()
@@ -612,14 +615,10 @@ func (pc *PartitionContext) addNodeToList(node *objects.Node) error {
 		zap.String("partitionName", pc.Name),
 		zap.String("nodeID", node.NodeID),
 		zap.Stringer("partitionResource", pc.totalPartitionResource))
-	return nil
 }
 
 // removeNodeFromList removes the node from the list of partition nodes.
-// This locks the partition.
 func (pc *PartitionContext) removeNodeFromList(nodeID string) *objects.Node {
-	pc.Lock()
-	defer pc.Unlock()
 	node := pc.nodes.RemoveNode(nodeID)
 	if node == nil {
 		log.Log(log.SchedPartition).Debug("node was not found, node already removed",
@@ -630,7 +629,6 @@ func (pc *PartitionContext) removeNodeFromList(nodeID string) *objects.Node {
 
 	// Remove node from list of tracked nodes
 	metrics.GetSchedulerMetrics().DecActiveNodes()
-
 	log.Log(log.SchedPartition).Info("Removed node from available partition nodes",
 		zap.String("partitionName", pc.Name),
 		zap.String("nodeID", node.NodeID))
@@ -1015,7 +1013,7 @@ func (pc *PartitionContext) GetTotalPartitionResource() *resources.Resource {
 	pc.RLock()
 	defer pc.RUnlock()
 
-	return pc.totalPartitionResource
+	return pc.totalPartitionResource.Clone()
 }
 
 func (pc *PartitionContext) GetAllocatedResource() *resources.Resource {
@@ -1032,8 +1030,6 @@ func (pc *PartitionContext) GetTotalAllocationCount() int {
 }
 
 func (pc *PartitionContext) GetTotalNodeCount() int {
-	pc.RLock()
-	defer pc.RUnlock()
 	return pc.nodes.GetNodeCount()
 }
 
@@ -1119,8 +1115,6 @@ func (pc *PartitionContext) cleanupExpiredApps() {
 
 // GetNodes returns a slice of all nodes unfiltered from the iterator
 func (pc *PartitionContext) GetNodes() []*objects.Node {
-	pc.RLock()
-	defer pc.RUnlock()
 	return pc.nodes.GetNodes()
 }
 
@@ -1442,15 +1436,11 @@ func (pc *PartitionContext) GetStateTime() time.Time {
 }
 
 func (pc *PartitionContext) GetNodeSortingPolicyType() policies.SortingPolicy {
-	pc.RLock()
-	defer pc.RUnlock()
 	policy := pc.nodes.GetNodeSortingPolicy()
 	return policy.PolicyType()
 }
 
 func (pc *PartitionContext) GetNodeSortingResourceWeights() map[string]float64 {
-	pc.RLock()
-	defer pc.RUnlock()
 	policy := pc.nodes.GetNodeSortingPolicy()
 	return policy.ResourceWeights()
 }
