@@ -50,7 +50,7 @@ func (filter Filter) allowUser(userObj security.UserGroup) bool {
 	filteredUser := filter.filterUser(user)
 	// if we have found the user in the list stop looking and return
 	if filteredUser {
-		log.Logger().Debug("Filter matched user getName", zap.String("user", user))
+		log.Log(log.Config).Debug("Filter matched user getName", zap.String("user", user))
 		return filteredUser && filter.allow
 	}
 	// not in the user list, check the groups in the list
@@ -58,7 +58,7 @@ func (filter Filter) allowUser(userObj security.UserGroup) bool {
 	for _, group := range groups {
 		filteredUser = filter.filterGroup(group)
 		if filteredUser {
-			log.Logger().Debug("Filter matched user group", zap.String("group", group))
+			log.Log(log.Config).Debug("Filter matched user group", zap.String("group", group))
 			return filteredUser && filter.allow
 		}
 	}
@@ -104,7 +104,7 @@ func newFilter(conf configs.Filter) Filter {
 		if configs.SpecialRegExp.MatchString(user) {
 			filter.userExp, err = regexp.Compile(user)
 			if err != nil {
-				log.Logger().Debug("Filter user expression does not compile", zap.Any("userFilter", conf.Users))
+				log.Log(log.Config).Debug("Filter user expression does not compile", zap.Any("userFilter", conf.Users))
 			}
 		} else if configs.UserRegExp.MatchString(user) {
 			// regexp not found consider this a user, sanity check the entry
@@ -122,14 +122,14 @@ func newFilter(conf configs.Filter) Filter {
 			}
 		}
 		if len(filter.userList) != len(conf.Users) {
-			log.Logger().Info("Filter creation duplicate or invalid users found", zap.Any("userFilter", conf.Users))
+			log.Log(log.Config).Info("Filter creation duplicate or invalid users found", zap.Any("userFilter", conf.Users))
 		}
 		filter.empty = false
 	}
 
 	// check what we have created
 	if len(conf.Users) > 0 && filter.userExp == nil && len(filter.userList) == 0 {
-		log.Logger().Info("Filter creation partially failed (user)", zap.Any("userFilter", conf.Users))
+		log.Log(log.Config).Info("Filter creation partially failed (user)", zap.Any("userFilter", conf.Users))
 	}
 
 	// create the group list or regexp
@@ -139,7 +139,7 @@ func newFilter(conf configs.Filter) Filter {
 		if configs.SpecialRegExp.MatchString(group) {
 			filter.groupExp, err = regexp.Compile(group)
 			if err != nil {
-				log.Logger().Debug("Filter group expression does not compile", zap.Any("groupFilter", conf.Groups))
+				log.Log(log.Config).Debug("Filter group expression does not compile", zap.Any("groupFilter", conf.Groups))
 			}
 		} else if configs.GroupRegExp.MatchString(group) {
 			// regexp not found consider this a group, sanity check the entry
@@ -157,36 +157,38 @@ func newFilter(conf configs.Filter) Filter {
 			}
 		}
 		if len(filter.groupList) != len(conf.Groups) {
-			log.Logger().Info("Filter creation duplicate or invalid groups found", zap.Any("groupFilter", conf.Groups))
+			log.Log(log.Config).Info("Filter creation duplicate or invalid groups found", zap.Any("groupFilter", conf.Groups))
 		}
 		filter.empty = false
 	}
 
 	// check what we have created
 	if len(conf.Groups) > 0 && filter.groupExp == nil && len(filter.groupList) == 0 {
-		log.Logger().Info("Filter creation partially failed (groups)", zap.Any("groupFilter", conf.Groups))
+		log.Log(log.Config).Info("Filter creation partially failed (groups)", zap.Any("groupFilter", conf.Groups))
 	}
 
 	// log the filter with all details (only at debug)
-	if log.IsDebugEnabled() {
-		var userfilter, groupfilter string
-		if filter.userExp == nil {
-			userfilter = "nil"
-		} else {
-			userfilter = filter.userExp.String()
-		}
-		if filter.groupExp == nil {
-			groupfilter = "nil"
-		} else {
-			groupfilter = filter.groupExp.String()
-		}
-		log.Logger().Debug("Filter creation passed",
-			zap.Bool("allow", filter.allow),
-			zap.Bool("empty", filter.empty),
-			zap.Any("userList", filter.userList),
-			zap.Any("groupList", filter.groupList),
-			zap.String("userFilter", userfilter),
-			zap.String("groupFilter", groupfilter))
-	}
+	logFilter(&filter)
 	return filter
 }
+
+func logFilter(filter *Filter) {
+	var userfilter, groupfilter string
+	if filter.userExp == nil {
+		userfilter = "nil"
+	} else {
+		userfilter = filter.userExp.String()
+	}
+	if filter.groupExp == nil {
+		groupfilter = "nil"
+	} else {
+		groupfilter = filter.groupExp.String()
+	}
+	log.Log(log.Config).Debug("Filter creation passed",
+		zap.Bool("allow", filter.allow),
+		zap.Bool("empty", filter.empty),
+		zap.Any("userList", filter.userList),
+		zap.Any("groupList", filter.groupList),
+		zap.String("userFilter", userfilter),
+		zap.String("groupFilter", groupfilter))
+}
