@@ -57,22 +57,26 @@ partitions:
 	// queue that does not exists directly under the root
 	appInfo := newApplication("app1", "default", "unknown", user, tags, nil, "")
 	var queue string
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	var aclCheck bool
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "" || err != nil {
 		t.Errorf("provided rule placed app in incorrect queue '%s', err %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 	// trying to place when no queue provided in the app
 	appInfo = newApplication("app1", "default", "", user, tags, nil, "")
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "" || err != nil {
 		t.Errorf("provided rule placed app in incorrect queue '%s', error %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 	// trying to place in a qualified queue that does not exist
 	appInfo = newApplication("app1", "default", "root.unknown", user, tags, nil, "")
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "" || err != nil {
 		t.Errorf("provided rule placed app in incorrect queue '%s', error %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 	// same queue now with create flag
 	conf = configs.PlacementRule{
 		Name:   "provided",
@@ -82,10 +86,11 @@ partitions:
 	if err != nil || pr == nil {
 		t.Errorf("provided rule create failed, err %v", err)
 	}
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "root.unknown" || err != nil {
 		t.Errorf("provided rule placed app in incorrect queue '%s', error %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 
 	conf = configs.PlacementRule{
 		Name: "provided",
@@ -101,18 +106,20 @@ partitions:
 
 	// unqualified queue with parent rule that exists directly in hierarchy
 	appInfo = newApplication("app1", "default", "testchild", user, tags, nil, "")
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "root.testparent.testchild" || err != nil {
 		t.Errorf("provided rule failed to place queue in correct queue '%s', err %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 
 	// qualified queue with parent rule (parent rule ignored)
 	appInfo = newApplication("app1", "default", "root.testparent", user, tags, nil, "")
 
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "root.testparent" || err != nil {
 		t.Errorf("provided rule placed in to be created queue with create false '%s', err %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 }
 
 func TestProvidedRuleParent(t *testing.T) {
@@ -142,10 +149,12 @@ func TestProvidedRuleParent(t *testing.T) {
 
 	appInfo := newApplication("app1", "default", "unknown", user, tags, nil, "")
 	var queue string
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	var aclCheck bool
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "" || err != nil {
 		t.Errorf("provided rule placed app in incorrect queue '%s', err %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 
 	// trying to place in a child using a non creatable parent
 	conf = configs.PlacementRule{
@@ -163,10 +172,11 @@ func TestProvidedRuleParent(t *testing.T) {
 	}
 
 	appInfo = newApplication("app1", "default", "testchild", user, tags, nil, "")
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "" || err != nil {
 		t.Errorf("provided rule placed app in incorrect queue '%s', err %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 
 	// trying to place in a child using a creatable parent
 	conf = configs.PlacementRule{
@@ -182,10 +192,11 @@ func TestProvidedRuleParent(t *testing.T) {
 	if err != nil || pr == nil {
 		t.Errorf("provided rule create failed, err %v", err)
 	}
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != nameParentChild || err != nil {
 		t.Errorf("provided rule with non existing parent queue should create '%s', error %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 
 	// trying to place in a child using a parent which is defined as a leaf
 	conf = configs.PlacementRule{
@@ -202,8 +213,9 @@ func TestProvidedRuleParent(t *testing.T) {
 	}
 
 	appInfo = newApplication("app1", "default", "unknown", user, tags, nil, "")
-	queue, err = pr.placeApplication(appInfo, queueFunc)
+	queue, aclCheck, err = pr.placeApplication(appInfo, queueFunc)
 	if queue != "" || err == nil {
 		t.Errorf("provided rule placed app in incorrect queue '%s', err %v", queue, err)
 	}
+	assert.Check(t, aclCheck, "acls should be checked")
 }
