@@ -57,35 +57,36 @@ func (tr *tagRule) initialise(conf configs.PlacementRule) error {
 	return err
 }
 
-func (tr *tagRule) placeApplication(app *objects.Application, queueFn func(string) *objects.Queue) (string, error) {
+func (tr *tagRule) placeApplication(app *objects.Application, queueFn func(string) *objects.Queue) (string, bool, error) {
 	// if the tag is not present we can skipp all other processing
 	tagVal := app.GetTag(tr.tagName)
 	if tagVal == "" {
-		return "", nil
+		return "", true, nil
 	}
 	// before anything run the filter
 	if !tr.filter.allowUser(app.GetUser()) {
-		log.Logger().Debug("Tag rule filtered",
+		log.Log(log.Config).Debug("Tag rule filtered",
 			zap.String("application", app.ApplicationID),
 			zap.Any("user", app.GetUser()),
 			zap.String("tagName", tr.tagName))
-		return "", nil
+		return "", true, nil
 	}
 	var parentName string
+	var aclCheck = true
 	var err error
 	queueName := tagVal
 	// if we have a fully qualified queue in the value do not run the parent rule
 	if !strings.HasPrefix(queueName, configs.RootQueue+configs.DOT) {
 		// run the parent rule if set
 		if tr.parent != nil {
-			parentName, err = tr.parent.placeApplication(app, queueFn)
+			parentName, aclCheck, err = tr.parent.placeApplication(app, queueFn)
 			// failed parent rule, fail this rule
 			if err != nil {
-				return "", err
+				return "", aclCheck, err
 			}
 			// rule did not match: this could be filter or create flag related
 			if parentName == "" {
-				return "", nil
+				return "", aclCheck, nil
 			}
 			// check if this is a parent queue and qualify it
 			if !strings.HasPrefix(parentName, configs.RootQueue+configs.DOT) {
@@ -94,7 +95,7 @@ func (tr *tagRule) placeApplication(app *objects.Application, queueFn func(strin
 			// if the parent queue exists it cannot be a leaf
 			parentQueue := queueFn(parentName)
 			if parentQueue != nil && parentQueue.IsLeafQueue() {
-				return "", fmt.Errorf("parent rule returned a leaf queue: %s", parentName)
+				return "", aclCheck, fmt.Errorf("parent rule returned a leaf queue: %s", parentName)
 			}
 		}
 		// the parent is set from the rule otherwise set it to the root
@@ -103,17 +104,17 @@ func (tr *tagRule) placeApplication(app *objects.Application, queueFn func(strin
 		}
 		queueName = parentName + configs.DOT + replaceDot(tagVal)
 	}
-	log.Logger().Debug("Tag rule intermediate result",
+	log.Log(log.Config).Debug("Tag rule intermediate result",
 		zap.String("application", app.ApplicationID),
 		zap.String("queue", queueName))
 	// get the queue object
 	queue := queueFn(queueName)
 	// if we cannot create the queue it must exist, rule does not match otherwise
 	if !tr.create && queue == nil {
-		return "", nil
+		return "", aclCheck, nil
 	}
-	log.Logger().Info("Tag rule application placed",
+	log.Log(log.Config).Info("Tag rule application placed",
 		zap.String("application", app.ApplicationID),
 		zap.String("queue", queueName))
-	return queueName, nil
+	return queueName, aclCheck, nil
 }
