@@ -55,7 +55,7 @@ partitions:
 	ms := &mockScheduler{}
 	defer ms.Stop()
 
-	err := ms.Init(configData, false)
+	err := ms.Init(configData, false, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
 	// Check queues of cache and scheduler.
@@ -68,7 +68,7 @@ partitions:
 
 	// Check scheduling queue a
 	queueA := part.GetQueue("root.a")
-	assert.Assert(t, 150000000 == queueA.GetMaxResource().Resources[common.Memory])
+	assert.Equal(t, resources.Quantity(150000000), queueA.GetMaxResource().Resources[common.Memory])
 
 	// Add one application
 	err = ms.proxy.UpdateApplication(&si.ApplicationRequest{
@@ -183,7 +183,7 @@ partitions:
 	ms := &mockScheduler{}
 	defer ms.Stop()
 
-	err := ms.Init(configData, false)
+	err := ms.Init(configData, false, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
 	// Check queues of cache and scheduler.
@@ -196,7 +196,7 @@ partitions:
 
 	// Check scheduling queue a
 	queueA := part.GetQueue("root.a")
-	assert.Assert(t, 150000000 == queueA.GetMaxResource().Resources[common.Memory])
+	assert.Equal(t, resources.Quantity(150000000), queueA.GetMaxResource().Resources[common.Memory])
 
 	// Add one application
 	err = ms.proxy.UpdateApplication(&si.ApplicationRequest{
@@ -331,7 +331,7 @@ partitions:
 	ms := &mockScheduler{}
 	defer ms.Stop()
 
-	err := ms.Init(configData, false)
+	err := ms.Init(configData, false, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
 	// Check queues of cache and scheduler.
@@ -447,7 +447,7 @@ partitions:
 	ms := &mockScheduler{}
 	defer ms.Stop()
 
-	err := ms.Init(configData, false)
+	err := ms.Init(configData, false, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
 	// Check queues of cache and scheduler.
@@ -566,7 +566,7 @@ partitions:
 	ms := &mockScheduler{}
 	defer ms.Stop()
 
-	err := ms.Init(configData, false)
+	err := ms.Init(configData, false, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
 	// Check queues of cache and scheduler.
