@@ -82,7 +82,7 @@ func InitAdmissionController(conf *conf.AdmissionControllerConf, pcCache *Priori
 		annotationHandler: metadata.NewUserGroupAnnotationHandler(conf),
 	}
 
-	log.Logger().Info("Initialized YuniKorn Admission Controller")
+	log.Log(log.Admission).Info("Initialized YuniKorn Admission Controller")
 	return hook
 }
 
@@ -95,7 +95,7 @@ func parseRegexes(patterns string) ([]*regexp.Regexp, error) {
 		}
 		re, err := regexp.Compile(pattern)
 		if err != nil {
-			log.Logger().Error("Unable to compile regular expression", zap.String("pattern", pattern), zap.Error(err))
+			log.Log(log.Admission).Error("Unable to compile regular expression", zap.String("pattern", pattern), zap.Error(err))
 			return nil, err
 		}
 		result = append(result, re)
@@ -123,14 +123,14 @@ func admissionResponseBuilder(uid string, allowed bool, resultMessage string, pa
 
 func (c *AdmissionController) mutate(req *admissionv1.AdmissionRequest) *admissionv1.AdmissionResponse {
 	if req == nil {
-		log.Logger().Warn("empty request received")
+		log.Log(log.Admission).Warn("empty request received")
 		return admissionResponseBuilder("", false, "", nil)
 	}
 	namespace := req.Namespace
 	if namespace == "" {
 		namespace = "default"
 	}
-	log.Logger().Info("AdmissionReview",
+	log.Log(log.Admission).Info("AdmissionReview",
 		zap.String("Namespace", namespace),
 		zap.String("UID", string(req.UID)),
 		zap.String("Operation", string(req.Operation)),
@@ -159,7 +159,7 @@ func (c *AdmissionController) processPod(req *admissionv1.AdmissionRequest, name
 
 	var pod v1.Pod
 	if err := json.Unmarshal(req.Object.Raw, &pod); err != nil {
-		log.Logger().Error("unmarshal failed", zap.Error(err))
+		log.Log(log.Admission).Error("unmarshal failed", zap.Error(err))
 		return admissionResponseBuilder(uid, false, err.Error(), nil)
 	}
 
@@ -174,7 +174,7 @@ func (c *AdmissionController) processPod(req *admissionv1.AdmissionRequest, name
 	}
 
 	if !userInfoSet && !c.conf.GetBypassAuth() {
-		log.Logger().Info("setting user info metadata on pod")
+		log.Log(log.Admission).Info("setting user info metadata on pod")
 		patchOp, err := c.annotationHandler.GetPatchForPod(pod.Annotations, userName, groups)
 		if err != nil {
 			return admissionResponseBuilder(uid, false, err.Error(), nil)
@@ -184,13 +184,13 @@ func (c *AdmissionController) processPod(req *admissionv1.AdmissionRequest, name
 
 	if labelAppValue := utils.GetPodLabelValue(&pod, constants.LabelApp); labelAppValue != "" {
 		if labelAppValue == yunikornPod {
-			log.Logger().Info("ignore yunikorn pod")
+			log.Log(log.Admission).Info("ignore yunikorn pod")
 			return admissionResponseBuilder(uid, true, "", nil)
 		}
 	}
 
 	if !c.shouldProcessNamespace(namespace) {
-		log.Logger().Info("bypassing namespace", zap.String("namespace", namespace))
+		log.Log(log.Admission).Info("bypassing namespace", zap.String("namespace", namespace))
 		return admissionResponseBuilder(uid, true, "", nil)
 	}
 	patch = updateSchedulerName(patch)
@@ -201,7 +201,7 @@ func (c *AdmissionController) processPod(req *admissionv1.AdmissionRequest, name
 	} else {
 		patch = disableYuniKorn(namespace, &pod, patch)
 	}
-	log.Logger().Info("generated patch",
+	log.Log(log.Admission).Info("generated patch",
 		zap.String("namespace", namespace),
 		zap.String("podName", pod.Name),
 		zap.String("generateName", pod.GenerateName),
@@ -209,7 +209,7 @@ func (c *AdmissionController) processPod(req *admissionv1.AdmissionRequest, name
 
 	patchBytes, err := json.Marshal(patch)
 	if err != nil {
-		log.Logger().Error("failed to marshal patch", zap.Error(err))
+		log.Log(log.Admission).Error("failed to marshal patch", zap.Error(err))
 		return admissionResponseBuilder(uid, false, err.Error(), nil)
 	}
 
@@ -236,7 +236,7 @@ func (c *AdmissionController) processWorkload(req *admissionv1.AdmissionRequest,
 	}
 
 	if !c.shouldProcessAdmissionReview(namespace, labels) {
-		log.Logger().Info("bypassing namespace", zap.String("namespace", namespace))
+		log.Log(log.Admission).Info("bypassing namespace", zap.String("namespace", namespace))
 		return admissionResponseBuilder(uid, true, "", nil)
 	}
 
@@ -263,16 +263,16 @@ func (c *AdmissionController) processWorkload(req *admissionv1.AdmissionRequest,
 	if !userInfoSet && !c.conf.GetBypassAuth() {
 		patch, err := c.annotationHandler.GetPatchForWorkload(req, userName, groups)
 		if err != nil {
-			log.Logger().Error("could not generate patch for workload", zap.Error(err))
+			log.Log(log.Admission).Error("could not generate patch for workload", zap.Error(err))
 			return admissionResponseBuilder(uid, false, err.Error(), nil)
 		}
 
 		patchBytes, patchErr := json.Marshal(patch)
 		if patchErr != nil {
-			log.Logger().Error("failed to marshal patch", zap.Error(patchErr))
+			log.Log(log.Admission).Error("failed to marshal patch", zap.Error(patchErr))
 			return admissionResponseBuilder(uid, false, patchErr.Error(), nil)
 		}
-		log.Logger().Info("updating annotations on workload", zap.String("type", req.Kind.Kind),
+		log.Log(log.Admission).Info("updating annotations on workload", zap.String("type", req.Kind.Kind),
 			zap.Any("generated patch", patch))
 		return admissionResponseBuilder(uid, true, "", patchBytes)
 	}
@@ -285,32 +285,32 @@ func (c *AdmissionController) processPodUpdate(req *admissionv1.AdmissionRequest
 
 	var newPod v1.Pod
 	if err := json.Unmarshal(req.Object.Raw, &newPod); err != nil {
-		log.Logger().Error("unmarshal failed", zap.Error(err))
+		log.Log(log.Admission).Error("unmarshal failed", zap.Error(err))
 		return admissionResponseBuilder(uid, false, err.Error(), nil)
 	}
 
 	var oldPod v1.Pod
 	if err := json.Unmarshal(req.OldObject.Raw, &oldPod); err != nil {
-		log.Logger().Error("unmarshal failed", zap.Error(err))
+		log.Log(log.Admission).Error("unmarshal failed", zap.Error(err))
 		return admissionResponseBuilder(uid, false, err.Error(), nil)
 	}
 
 	if labelAppValue, ok := newPod.Labels[constants.LabelApp]; ok {
 		if labelAppValue == yunikornPod {
-			log.Logger().Info("pod update - ignore yunikorn pod")
+			log.Log(log.Admission).Info("pod update - ignore yunikorn pod")
 			return admissionResponseBuilder(uid, true, "", nil)
 		}
 	}
 
 	if !c.shouldProcessAdmissionReview(namespace, newPod.Labels) {
-		log.Logger().Info("pod update - bypassing namespace", zap.String("namespace", namespace))
+		log.Log(log.Admission).Info("pod update - bypassing namespace", zap.String("namespace", namespace))
 		return admissionResponseBuilder(uid, true, "", nil)
 	}
 
 	originalUserInfo := oldPod.Annotations[common.UserInfoAnnotation]
 	newUserInfo := newPod.Annotations[common.UserInfoAnnotation]
 
-	log.Logger().Debug("checking original and new pod annotation", zap.String("original", originalUserInfo),
+	log.Log(log.Admission).Debug("checking original and new pod annotation", zap.String("original", originalUserInfo),
 		zap.String("new", newUserInfo))
 
 	if originalUserInfo != newUserInfo {
@@ -335,7 +335,7 @@ func (c *AdmissionController) shouldProcessWorkload(req *admissionv1.AdmissionRe
 	if req.Kind.Kind == metadata.ReplicaSet {
 		for _, sysUser := range c.conf.GetSystemUsers() {
 			if sysUser.MatchString(req.UserInfo.Username) {
-				log.Logger().Info("ReplicaSet was created by a system user, skipping it",
+				log.Log(log.Admission).Info("ReplicaSet was created by a system user, skipping it",
 					zap.String("uid", string(req.UID)))
 				return false
 			}
@@ -351,14 +351,14 @@ func (c *AdmissionController) checkUserInfoAnnotation(getAnnotation func() (stri
 		if allowed := c.annotationHandler.IsAnnotationAllowed(userName, groups); !allowed {
 			errMsg := fmt.Sprintf("user %s with groups [%s] is not allowed to set user annotation", userName,
 				strings.Join(groups, ","))
-			log.Logger().Error("user info validation failed - submitter is not allowed to set user annotation",
+			log.Log(log.Admission).Error("user info validation failed - submitter is not allowed to set user annotation",
 				zap.String("user", userName),
 				zap.Strings("groups", groups))
 			return admissionResponseBuilder(uid, false, errMsg, nil), userInfoSet
 		}
 
 		if err := c.annotationHandler.IsAnnotationValid(annotation); err != nil {
-			log.Logger().Error("invalid user info metadata", zap.Error(err))
+			log.Log(log.Admission).Error("invalid user info metadata", zap.Error(err))
 			return admissionResponseBuilder(uid, false, err.Error(), nil), userInfoSet
 		}
 	}
@@ -367,7 +367,7 @@ func (c *AdmissionController) checkUserInfoAnnotation(getAnnotation func() (stri
 }
 
 func updateSchedulerName(patch []common.PatchOperation) []common.PatchOperation {
-	log.Logger().Info("updating scheduler name")
+	log.Log(log.Admission).Info("updating scheduler name")
 	return append(patch, common.PatchOperation{
 		Op:    "add",
 		Path:  "/spec/schedulerName",
@@ -391,7 +391,7 @@ func (c *AdmissionController) updatePreemptionInfo(pod *v1.Pod, patch []common.P
 		value = constants.True
 	}
 
-	log.Logger().Info("updating pod preemption annotations",
+	log.Log(log.Admission).Info("updating pod preemption annotations",
 		zap.String("podName", pod.Name),
 		zap.String("allowPreemption", value))
 
@@ -416,7 +416,7 @@ func (c *AdmissionController) updatePreemptionInfo(pod *v1.Pod, patch []common.P
 }
 
 func (c *AdmissionController) updateLabels(namespace string, pod *v1.Pod, patch []common.PatchOperation) []common.PatchOperation {
-	log.Logger().Info("updating pod labels",
+	log.Log(log.Admission).Info("updating pod labels",
 		zap.String("podName", pod.Name),
 		zap.String("generateName", pod.GenerateName),
 		zap.String("namespace", namespace),
@@ -434,7 +434,7 @@ func (c *AdmissionController) updateLabels(namespace string, pod *v1.Pod, patch
 }
 
 func disableYuniKorn(namespace string, pod *v1.Pod, patch []common.PatchOperation) []common.PatchOperation {
-	log.Logger().Info("disabling yunikorn on pod since namespace is set to no-label",
+	log.Log(log.Admission).Info("disabling yunikorn on pod since namespace is set to no-label",
 		zap.String("podName", pod.Name),
 		zap.String("generateName", pod.GenerateName),
 		zap.String("namespace", namespace))
@@ -452,7 +452,7 @@ func disableYuniKorn(namespace string, pod *v1.Pod, patch []common.PatchOperatio
 
 func (c *AdmissionController) validateConf(req *admissionv1.AdmissionRequest) *admissionv1.AdmissionResponse {
 	if req == nil {
-		log.Logger().Warn("empty request received")
+		log.Log(log.Admission).Warn("empty request received")
 		return admissionResponseBuilder("", false, "", nil)
 	}
 
@@ -460,7 +460,7 @@ func (c *AdmissionController) validateConf(req *admissionv1.AdmissionRequest) *a
 
 	var requestKind = req.Kind.Kind
 	if requestKind != "ConfigMap" {
-		log.Logger().Warn("request kind is not configmap", zap.String("requestKind", requestKind))
+		log.Log(log.Admission).Warn("request kind is not configmap", zap.String("requestKind", requestKind))
 		return admissionResponseBuilder(uid, true, "", nil)
 	}
 
@@ -471,13 +471,13 @@ func (c *AdmissionController) validateConf(req *admissionv1.AdmissionRequest) *a
 
 	var configmap v1.ConfigMap
 	if err := json.Unmarshal(req.Object.Raw, &configmap); err != nil {
-		log.Logger().Error("failed to unmarshal configmap", zap.Error(err))
+		log.Log(log.Admission).Error("failed to unmarshal configmap", zap.Error(err))
 		return admissionResponseBuilder(uid, false, err.Error(), nil)
 	}
 
 	// validate new/updated config map
 	if err := c.validateConfigMap(namespace, &configmap); err != nil {
-		log.Logger().Error("failed to validate yunikorn configs", zap.Error(err))
+		log.Log(log.Admission).Error("failed to validate yunikorn configs", zap.Error(err))
 		return admissionResponseBuilder(uid, false, err.Error(), nil)
 	}
 
@@ -557,7 +557,7 @@ func (c *AdmissionController) shouldLabelNamespace(namespace string) bool {
 
 func (c *AdmissionController) validateConfigMap(namespace string, cm *v1.ConfigMap) error {
 	if namespace != c.conf.GetNamespace() {
-		log.Logger().Debug("Configmap does not belong to YuniKorn", zap.String("namespace", namespace), zap.String("Name", cm.Name))
+		log.Log(log.Admission).Debug("Configmap does not belong to YuniKorn", zap.String("namespace", namespace), zap.String("Name", cm.Name))
 		return nil
 	}
 
@@ -568,7 +568,7 @@ func (c *AdmissionController) validateConfigMap(namespace string, cm *v1.ConfigM
 	case constants.ConfigMapName:
 		configMaps[1] = cm
 	default:
-		log.Logger().Debug("Configmap does not belong to YuniKorn", zap.String("namespace", namespace), zap.String("Name", cm.Name))
+		log.Log(log.Admission).Debug("Configmap does not belong to YuniKorn", zap.String("namespace", namespace), zap.String("Name", cm.Name))
 		return nil
 	}
 
@@ -578,41 +578,41 @@ func (c *AdmissionController) validateConfigMap(namespace string, cm *v1.ConfigM
 
 	content, ok := configs[confKey]
 	if !ok {
-		log.Logger().Info("Configmap missing policygroup config, using default", zap.String("entry", confKey))
+		log.Log(log.Admission).Info("Configmap missing policygroup config, using default", zap.String("entry", confKey))
 		content = ""
 	}
 
 	checksum := fmt.Sprintf("%X", sha256.Sum256([]byte(content)))
-	log.Logger().Info("Validating YuniKorn configuration", zap.String("checksum", checksum))
-	log.Logger().Debug("Configmap data", zap.ByteString("content", []byte(content)))
+	log.Log(log.Admission).Info("Validating YuniKorn configuration", zap.String("checksum", checksum))
+	log.Log(log.Admission).Debug("Configmap data", zap.ByteString("content", []byte(content)))
 	response, err := http.Post(fmt.Sprintf(schedulerValidateConfURLPattern, c.conf.GetSchedulerServiceAddress()), "application/json", bytes.NewBuffer([]byte(content)))
 	if err != nil {
-		log.Logger().Error("YuniKorn scheduler is unreachable, assuming configmap is valid", zap.Error(err))
+		log.Log(log.Admission).Error("YuniKorn scheduler is unreachable, assuming configmap is valid", zap.Error(err))
 		return nil
 	}
 	defer response.Body.Close()
 	if response.StatusCode < 200 || response.StatusCode > 299 {
-		log.Logger().Error("YuniKorn scheduler responded with unexpected status, assuming configmap is valid",
+		log.Log(log.Admission).Error("YuniKorn scheduler responded with unexpected status, assuming configmap is valid",
 			zap.Int("status", response.StatusCode))
 		return nil
 	}
 	responseBytes, err := io.ReadAll(response.Body)
 	if err != nil {
-		log.Logger().Error("Unable to read response from YuniKorn scheduler, assuming configmap is valid", zap.Error(err))
+		log.Log(log.Admission).Error("Unable to read response from YuniKorn scheduler, assuming configmap is valid", zap.Error(err))
 		return nil
 	}
 	var responseData ValidateConfResponse
 	if err = json.Unmarshal(responseBytes, &responseData); err != nil {
-		log.Logger().Error("Unable to parse response from YuniKorn scheduler, assuming configmap is valid", zap.Error(err))
+		log.Log(log.Admission).Error("Unable to parse response from YuniKorn scheduler, assuming configmap is valid", zap.Error(err))
 		return nil
 	}
 	if !responseData.Allowed {
 		err = fmt.Errorf(responseData.Reason)
-		log.Logger().Error("Configmap validation failed, aborting", zap.Error(err))
+		log.Log(log.Admission).Error("Configmap validation failed, aborting", zap.Error(err))
 		return err
 	}
 
-	log.Logger().Info("Successfully validated YuniKorn configuration")
+	log.Log(log.Admission).Info("Successfully validated YuniKorn configuration")
 	return nil
 }
 
@@ -622,19 +622,19 @@ func (c *AdmissionController) Health(w http.ResponseWriter, r *http.Request) {
 	w.WriteHeader(200)
 	_, err := w.Write([]byte("OK\r\n"))
 	if err != nil {
-		log.Logger().Error("Unable to write health check result", zap.Error(err))
+		log.Log(log.Admission).Error("Unable to write health check result", zap.Error(err))
 		return
 	}
 }
 
 func (c *AdmissionController) Serve(w http.ResponseWriter, r *http.Request) {
-	log.Logger().Debug("request", zap.Any("httpRequest", r))
+	log.Log(log.Admission).Debug("request", zap.Any("httpRequest", r))
 	var body []byte
 	if r.Body != nil {
 		var err error
 		body, err = io.ReadAll(r.Body)
 		if err != nil || len(body) == 0 {
-			log.Logger().Debug("illegal request received: body invalid", zap.Error(err))
+			log.Log(log.Admission).Debug("illegal request received: body invalid", zap.Error(err))
 			http.Error(w, "empty or invalid body", http.StatusBadRequest)
 			return
 		}
@@ -643,14 +643,14 @@ func (c *AdmissionController) Serve(w http.ResponseWriter, r *http.Request) {
 	// verify the content type is accurate
 	contentType := r.Header.Get("Content-Type")
 	if contentType != "application/json" {
-		log.Logger().Debug("illegal request received: invalid content type", zap.String("requested content type", contentType))
+		log.Log(log.Admission).Debug("illegal request received: invalid content type", zap.String("requested content type", contentType))
 		http.Error(w, "invalid Content-Type, expect `application/json`", http.StatusUnsupportedMediaType)
 		return
 	}
 
 	urlPath := r.URL.Path
 	if urlPath != mutateURL && urlPath != validateConfURL {
-		log.Logger().Debug("unsupported request received", zap.String("urlPath", urlPath))
+		log.Log(log.Admission).Debug("unsupported request received", zap.String("urlPath", urlPath))
 		http.Error(w, "request is neither mutation nor validation", http.StatusNotFound)
 		return
 	}
@@ -662,7 +662,7 @@ func (c *AdmissionController) Serve(w http.ResponseWriter, r *http.Request) {
 	var admissionResponse *admissionv1.AdmissionResponse
 	_, _, err := deserializer.Decode(body, nil, &ar)
 	if err != nil || ar.Request == nil {
-		log.Logger().Error("request body decode failed or request empty", zap.Error(err))
+		log.Log(log.Admission).Error("request body decode failed or request empty", zap.Error(err))
 		admissionResponse = admissionResponseBuilder("yunikorn-invalid-body", false, "body decode failed", nil)
 	} else {
 		req := ar.Request
@@ -685,13 +685,13 @@ func (c *AdmissionController) Serve(w http.ResponseWriter, r *http.Request) {
 	resp, err = json.Marshal(admissionReview)
 	if err != nil {
 		errMessage := fmt.Sprintf("could not encode response: %v", err)
-		log.Logger().Error(errMessage)
+		log.Log(log.Admission).Error(errMessage)
 		http.Error(w, errMessage, http.StatusInternalServerError)
 	}
 
 	if _, err = w.Write(resp); err != nil {
 		errMessage := fmt.Sprintf("could not write response: %v", err)
-		log.Logger().Error(errMessage)
+		log.Log(log.Admission).Error(errMessage)
 		http.Error(w, errMessage, http.StatusInternalServerError)
 	}
 }
