@@ -42,7 +42,7 @@ const RootQueue = "root"
 const AnnotationQueueName = DomainYuniKorn + "queue"
 const AnnotationParentQueue = DomainYuniKorn + "parentqueue"
 const LabelDisableStateAware = "disableStateAware"
-const ApplicationDefaultQueue = "root.sandbox"
+const ApplicationDefaultQueue = "root.default"
 const DefaultPartition = "default"
 const AppTagNamespace = "namespace"
 const AppTagNamespaceParentQueue = "namespace.parentqueue"
