@@ -55,11 +55,12 @@ import { ContainerHistoryComponent } from '@app/components/container-history/con
 import { QueueRackComponent } from '@app/components/queue-rack/queue-rack.component';
 import { AppsViewComponent } from '@app/components/apps-view/apps-view.component';
 import { NodesViewComponent } from '@app/components/nodes-view/nodes-view.component';
+import { HighlightSearchPipe } from '@app/components/nodes-view/highlighttable-search.pipe';
 import { ErrorViewComponent } from '@app/components/error-view/error-view.component';
 import { StatusViewComponent } from '@app/components/status-view/status-view.component';
 import { HealthchecksComponent } from '@app/components/healthchecks/healthchecks.component';
-import { AppNodeUtilizationComponent } from '@app/components/app-node-utilization/app-node-utilization.component';
-import { BarChartComponent } from '@app/components/bar-chart/bar-chart.component';
+import { AppNodeUtilizationsComponent } from '@app/components/app-node-utilizations/app-node-utilizations.component';
+import { VerticalBarChartComponent } from '@app/components/vertical-bar-chart/vertical-bar-chart.component';
 
 @NgModule({
   declarations: [
@@ -75,11 +76,12 @@ import { BarChartComponent } from '@app/components/bar-chart/bar-chart.component
     QueueRackComponent,
     AppsViewComponent,
     NodesViewComponent,
+    HighlightSearchPipe,
     ErrorViewComponent,
     StatusViewComponent,
     HealthchecksComponent,
-    AppNodeUtilizationComponent,
-    BarChartComponent,
+    AppNodeUtilizationsComponent,
+    VerticalBarChartComponent,
   ],
   imports: [
     BrowserModule,
